# twitcasting-py
A unofficial python module for wrapping TwitCasting common APIs

# Usage

1. Install

```bash
pip install twitcasting_py
```

2. Import

```python
import twitcasting
```

3. Use

```python3
twitcasting.get_video_id('user_id')
```

# License

MIT